@@ -3,7 +3,7 @@ BEGIN {
   $App::DuckPAN::Web::AUTHORITY = 'cpan:DDG';
 }
 # ABSTRACT: Webserver for duckpan server
-$App::DuckPAN::Web::VERSION = '0.148';
+$App::DuckPAN::Web::VERSION = '0.149';
 use Moo;
 use DDG::Request;
 use DDG::Test::Location;
@@ -272,7 +272,8 @@ sub request {
 					} elsif ($_->filename =~ /^.+handlebars$/){
 						my $template_name = $_->filename;
 						$template_name =~ s/\.handlebars//;
-						$calls_template{$spice_name}{$template_name} = $_;
+						$calls_template{$spice_name}{$template_name}{"content"} = $_;
+						$calls_template{$spice_name}{$template_name}{"is_ct_self"} = $result->call_type eq 'self';
 					}
 				}
 				push (@calls_nrj, $result->call_path);
@@ -349,12 +350,12 @@ sub request {
 			: '';
 
 		if (%calls_template) {
-
 			foreach my $spice_name ( keys %calls_template ){
 				$calls_script .= join("",map {
 					my $template_name = $_;
-					my $template_content = $calls_template{$spice_name}{$template_name}->slurp;
-					"<script class='duckduckhack_spice_template' spice-name='$spice_name' template-name='$template_name' type='text/plain'>$template_content</script>"
+					my $is_ct_self = $calls_template{$spice_name}{$template_name}{"is_ct_self"};
+					my $template_content = $calls_template{$spice_name}{$template_name}{"content"}->slurp;
+					"<script class='duckduckhack_spice_template' spice-name='$spice_name' template-name='$template_name' is-ct-self='$is_ct_self' type='text/plain'>$template_content</script>"
 
 				} keys $calls_template{$spice_name});
 			}
@@ -397,7 +398,7 @@ App::DuckPAN::Web - Webserver for duckpan server
 
 =head1 VERSION
 
-version 0.148
+version 0.149
 
 =head1 AUTHOR
 
